import os
import csv
from ExceptionHelper import FileNotExistError
from StringIO import StringIO


def csv2dict(input_file):
    """
    Convert csv data to dictionary, the result will be stored in data attribute

    @param input_file : path to the excel file or a StringIO object
    @type input_file: str | StringIO
    @return: list[dict]
    @raise FileNotExistError: File does not exist
    @raise TypeError: File parameter is not of type str or StringIO
    """
    data = []

    if type(input_file) is str:
        # input_file is a path
        if not os.access(input_file, os.F_OK):
            raise FileNotExistError('Cannot find the csv file [%s]' % input_file)

        with open(input_file, 'rb') as f:
            rows = csv.DictReader(f)
            for row in rows:
                data.append(row)

        return data

    elif isinstance(input_file, StringIO):
        # input_file is a StringIO object
        rows = csv.DictReader(input_file)
        for row in rows:
            data.append(row)

        return data

    else:
        raise TypeError('input_file argument but be of type str or StringIO')
